@@ -1,7 +1,8 @@
 #' Add rows to data.frame/matrix/table
 #'
-#' \code{add_rows} is similar to \link[base]{rbind} but it handles non-matching 
-#' column names. \code{\%add_rows\%} is an infix version of \code{add_rows}. 
+#' Take a sequence of vector, matrix or data-frame arguments and combine by
+#' rows. Contrary to \link[base:cbind]{rbind} it handles non-matching column
+#' names. \code{\%add_rows\%} is an infix version of \code{add_rows}.
 #' There is also special method for the results of
 #' \link{cro}/\link{cro_fun}/\link{tables}/\link{fre}. \code{.add_rows} is
 #' version for adding rows to default dataset. See \link{default_dataset}.
@@ -14,7 +15,7 @@
 #'   \code{"add"} will combine all columns, \code{"drop"} will leave only common
 #'   columns, \code{"stop"} will raise an error.
 #'
-#' @return See \link[base]{rbind}, \link{cro}, \link{cro_fun}, \link{fre}, \link{tables} 
+#' @return See \link[base:cbind]{rbind}, \link{cro}, \link{cro_fun}, \link{fre}, \link{tables} 
 #' @export
 #'
 #' @examples
@@ -50,7 +51,7 @@
 #' 
 #' tbl_mean %add_rows% tbl_percent
 #'
-add_rows = function(..., nomatch_columns = c("add", "drop", "stop")){
+add_rows = function(...){
     UseMethod("add_rows")
 }
 
