@@ -1,7 +1,7 @@
 if(capabilities('long.double')){
-    # library(testthat)
-    # library(expss)
+    library(testthat)
+    library(expss)
+    options(covr = FALSE)
     options(width = 1000)
-    options(covr = TRUE)
     testthat::test_check("expss")
 }
\ No newline at end of file
