@@ -19,12 +19,12 @@ mtcars = apply_labels(mtcars,
 tab = calculate(mtcars, cro_cpct(list(cyl, gear, carb), list("#total", vs, am)))
 expect_equal_to_reference(
     tab_sort_asc(tab),
-    "rds/tab_sort_1.rds"
+    "rds/tab_sort_1.rds",  update = FALSE
 )
 
 expect_equal_to_reference(
     tab_sort_desc(tab),
-    "rds/tab_sort_2.rds"
+    "rds/tab_sort_2.rds",  update = FALSE
 )
 
 tab = calculate(mtcars, cro_cpct(list(cyl, gear, carb), list("#total", vs, am), 
@@ -32,12 +32,12 @@ tab = calculate(mtcars, cro_cpct(list(cyl, gear, carb), list("#total", vs, am),
 
 expect_equal_to_reference(
     tab_sort_asc(tab),
-    "rds/tab_sort_3.rds"
+    "rds/tab_sort_3.rds",  update = FALSE
 )
 
 expect_equal_to_reference(
     tab_sort_desc(tab),
-    "rds/tab_sort_4.rds"
+    "rds/tab_sort_4.rds",  update = FALSE
 )
 
 expect_identical(
@@ -50,75 +50,75 @@ tab = calculate(mtcars, cro_cpct(list(cyl, gear, carb), list("#total", vs, am),
 
 expect_equal_to_reference(
     tab_sort_asc(tab),
-    "rds/tab_sort_5.rds"
+    "rds/tab_sort_5.rds",  update = FALSE
 )
 
 expect_equal_to_reference(
     tab_sort_desc(tab),
-    "rds/tab_sort_6.rds"
+    "rds/tab_sort_6.rds",  update = FALSE
 )
 
 expect_equal_to_reference(
     tab_sort_asc(tab[FALSE,]),
-    "rds/tab_sort_7.rds"
+    "rds/tab_sort_7.rds",  update = FALSE
 )
 
 expect_equal_to_reference(
     tab_sort_desc(tab[FALSE,]),
-    "rds/tab_sort_7.rds"
+    "rds/tab_sort_7.rds",  update = FALSE
 )
 
 tab = calculate(mtcars, cro_cpct(list(cyl, gear, carb), list("#total", vs, am)))
 expect_equal_to_reference(
     tab_sort_asc(tab, excluded_rows = grepl("#|8", tab[[1]], perl = TRUE)),
-    "rds/tab_sort_8.rds"
+    "rds/tab_sort_8.rds",  update = FALSE
 )
 
 expect_equal_to_reference(
     tab_sort_desc(tab, excluded_rows = grepl("#|1", tab[[1]], perl = TRUE)),
-    "rds/tab_sort_9.rds"
+    "rds/tab_sort_9.rds",  update = FALSE
 )
 
 
 expect_equal_to_reference(
     tab_sort_asc(tab, excluded_rows = grep("#|8", tab[[1]], perl = TRUE)),
-    "rds/tab_sort_8.rds"
+    "rds/tab_sort_8.rds",  update = FALSE
 )
 
 expect_equal_to_reference(
     tab_sort_desc(tab, excluded_rows = grep("#|1", tab[[1]], perl = TRUE)),
-    "rds/tab_sort_9.rds"
+    "rds/tab_sort_9.rds",  update = FALSE
 )
 
 
 expect_equal_to_reference(
     tab_sort_asc(tab, excluded_rows = "#|8"),
-    "rds/tab_sort_8.rds"
+    "rds/tab_sort_8.rds",  update = FALSE
 )
 
 expect_equal_to_reference(
     tab_sort_desc(tab, excluded_rows = "#|1"),
-    "rds/tab_sort_9.rds"
+    "rds/tab_sort_9.rds",  update = FALSE
 )
 
 expect_equal_to_reference(
     tab_sort_asc(tab, excluded_rows = c("#","8")),
-    "rds/tab_sort_8.rds"
+    "rds/tab_sort_8.rds",  update = FALSE
 )
 
 expect_equal_to_reference(
     tab_sort_desc(tab, excluded_rows = c("#","1")),
-    "rds/tab_sort_9.rds"
+    "rds/tab_sort_9.rds",  update = FALSE
 )
 
 expect_equal_to_reference(
     tab_sort_asc(tab, "Engine|V-engine"),
-    "rds/tab_sort_10.rds"
+    "rds/tab_sort_10.rds",  update = FALSE
 )
 
 expect_equal_to_reference(
     tab_sort_desc(tab, "Engine|V-engine"),
-    "rds/tab_sort_11.rds"
+    "rds/tab_sort_11.rds",  update = FALSE
 )
 
 param = "Engine|V-engine"
@@ -130,12 +130,12 @@ expect_error(
 
 expect_equal_to_reference(
     tab_sort_desc(tab, (param)),
-    "rds/tab_sort_11.rds"
+    "rds/tab_sort_11.rds",  update = FALSE
 )
 
 expect_equal_to_reference(
     tab_sort_asc(tab, perl("V-engine")),
-    "rds/tab_sort_10.rds"
+    "rds/tab_sort_10.rds",  update = FALSE
 )
 
 expect_identical(
