@@ -70,14 +70,17 @@ w2 = 2.5
 
 w_prep = if_val(w, NA ~ 0, lt(0) ~ 0, other ~ copy)
 w_prep2 = rep(w2, length(x))
+no_na = !is.na(x) & !is.na(w)
+x_no_na = x[no_na]
+w_no_na = w[no_na]
 expect_equal(w_mean(x, w), weighted.mean(x, w_prep, na.rm = TRUE))
 expect_equal(w_sum(x, w), sum(x*w_prep, na.rm = TRUE))
 expect_equal(w_median(x, w),
-                 matrixStats:::weightedMedian(x, w, na.rm = TRUE, interpolate = TRUE, ties = "weighted"))
+                 matrixStats:::weightedMedian(x_no_na, w_no_na, interpolate = TRUE, ties = "weighted"))
 expect_equal(w_mad(x, w),
-                 matrixStats:::weightedMad(x, w, na.rm = TRUE, center = w_median(x, w, na.rm = TRUE)))
-expect_equal(w_sd(x, w), matrixStats:::weightedSd(x, w_prep, na.rm = TRUE))
-expect_equal(w_var(x, w), matrixStats:::weightedVar(x, w_prep, na.rm = TRUE))
+                 matrixStats:::weightedMad(x_no_na, w_no_na,  center = w_median(x, w, na.rm = TRUE)))
+expect_equal(w_sd(x, w), matrixStats:::weightedSd(x_no_na, w_no_na))
+expect_equal(w_var(x, w), matrixStats:::weightedVar(x_no_na, w_no_na))
 expect_equal(w_n(x, w), sum((!is.na(x))*w_prep))
 expect_equal(w_se(x, w), 0.09577068)
 
@@ -88,11 +91,11 @@ w = as.matrix(w)
 expect_equal(w_mean(x, w), weighted.mean(x, w_prep, na.rm = TRUE))
 expect_equal(w_sum(x, w), sum(x*w_prep, na.rm = TRUE))
 expect_equal(w_median(x, w),
-                 matrixStats:::weightedMedian(x, w, na.rm = TRUE, interpolate = TRUE, ties = "weighted"))
+                 matrixStats:::weightedMedian(x_no_na, w_no_na, interpolate = TRUE, ties = "weighted"))
 expect_equal(w_mad(x, w),
-                 matrixStats:::weightedMad(x, w, na.rm = TRUE, center = w_median(x, w, na.rm = TRUE)))
-expect_equal(w_sd(x, w), matrixStats:::weightedSd(x, w_prep, na.rm = TRUE))
-expect_equal(w_var(x, w), matrixStats:::weightedVar(x, w_prep, na.rm = TRUE))
+                 matrixStats:::weightedMad(x_no_na, w_no_na, center = w_median(x, w, na.rm = TRUE)))
+expect_equal(w_sd(x, w), matrixStats:::weightedSd(x_no_na, w_no_na))
+expect_equal(w_var(x, w), matrixStats:::weightedVar(x_no_na, w_no_na))
 expect_equal(w_n(x, w), sum((!is.na(x))*w_prep))
 expect_equal(w_se(x, w), 0.09577068)
 
@@ -162,14 +165,18 @@ expect_equal(w_n(x, w), 8.11697)
 w_prep = w_prep[-1]
 x = x[-1]
 w = w[-1]
+
+no_na = !is.na(x) & !is.na(w)
+x_no_na = x[no_na]
+w_no_na = w[no_na]
 expect_equal(w_mean(x, w, na.rm = FALSE), weighted.mean(x, w_prep, na.rm = TRUE))
 expect_equal(w_sum(x, w, na.rm = FALSE), sum(x*w_prep, na.rm = TRUE))
 expect_equal(w_median(x, w, na.rm = FALSE),
-                 matrixStats::weightedMedian(x, w, na.rm = TRUE, interpolate = TRUE, ties = "weighted"))
+                 matrixStats::weightedMedian(x_no_na, w_no_na, interpolate = TRUE, ties = "weighted"))
 expect_equal(w_mad(x, w, na.rm = FALSE),
-                 matrixStats::weightedMad(x, w, na.rm = TRUE, center = w_median(x, w, na.rm = FALSE)))
-expect_equal(w_sd(x, w, na.rm = FALSE), matrixStats::weightedSd(x, w_prep, na.rm = TRUE))
-expect_equal(w_var(x, w, na.rm = FALSE), matrixStats::weightedVar(x, w_prep, na.rm = TRUE))
+                 matrixStats::weightedMad(x_no_na, w_no_na, center = w_median(x, w, na.rm = FALSE)))
+expect_equal(w_sd(x, w, na.rm = FALSE), matrixStats::weightedSd(x_no_na, w_no_na))
+expect_equal(w_var(x, w, na.rm = FALSE), matrixStats::weightedVar(x_no_na, w_no_na))
 expect_equal(w_n(x, w, na.rm = FALSE), sum((!is.na(x))*w_prep))
 
 ###################################################
